@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Create network transition chord progressions
 
-our $VERSION = '0.0600';
+our $VERSION = '0.0601';
 
 use Carp qw(croak);
 use Data::Dumper::Compact qw(ddc);
@@ -333,7 +333,7 @@ Music::Chord::Progression - Create network transition chord progressions
 
 =head1 VERSION
 
-version 0.0600
+version 0.0601
 
 =head1 SYNOPSIS
 
@@ -498,7 +498,7 @@ Default: C<0>
 
 The network transition L<Graph> object.  This is a computed attribute.
 
-Default: C<Graph::Directed>
+Default: C<Graph::Directed-E<gt>new>
 
 =head2 phrase
 
@@ -538,13 +538,14 @@ Create a new C<Music::Chord::Progression> object.
 
   $chords = $prog->generate;
 
-Generate a fresh chord progression.
+Generate a fresh chord progression and set the B<phrase> and B<chords>
+attributes.
 
 =head2 substitution
 
   $substitute = $prog->substitution($chord_name);
 
-Perform a jazz substitution on the given the B<chord_name>.
+Perform a jazz substitution on the given the named chord.
 
 =head1 SEE ALSO
 
